@@ -31,14 +31,21 @@
 #define ARES_COPYRIGHT "2004 - 2024 Daniel Stenberg, <daniel@haxx.se>."
 
 #define ARES_VERSION_MAJOR 1
-#define ARES_VERSION_MINOR 32
-#define ARES_VERSION_PATCH 2
+#define ARES_VERSION_MINOR 34
+#define ARES_VERSION_PATCH 1
+
 #define ARES_VERSION                                        \
   ((ARES_VERSION_MAJOR << 16) | (ARES_VERSION_MINOR << 8) | \
    (ARES_VERSION_PATCH))
-#define ARES_VERSION_STR "1.32.2"
 
-#define CARES_HAVE_ARES_LIBRARY_INIT    1
-#define CARES_HAVE_ARES_LIBRARY_CLEANUP 1
+
+/* Need a level of indirection due to argument prescan to stringify a macro
+ * value. */
+#define ARES_STRINGIFY_PRE(s) #s
+#define ARES_STRINGIFY(s)     ARES_STRINGIFY_PRE(s)
+
+#define ARES_VERSION_STR             \
+  ARES_STRINGIFY(ARES_VERSION_MAJOR) \
+  "." ARES_STRINGIFY(ARES_VERSION_MINOR) "." ARES_STRINGIFY(ARES_VERSION_PATCH)
 
 #endif
